@@ -34,18 +34,18 @@
 #include <sys/stat.h>
 
 #include <stdio.h>
-#ifdef STDC_HEADERS
+#ifdef HAVE_STDLIB_H
 # include <stdlib.h>
-#endif /* STDC_HEADERS */
+#endif /* HAVE_STDLIB_H */
 #ifdef HAVE_STRING_H
 # include <string.h>
 #endif /* HAVE_STRING_H */
 #ifdef HAVE_STRINGS_H
 # include <strings.h>
 #endif /* HAVE_STRINGS_H */
-#if defined(HAVE_MALLOC_H) && !defined(STDC_HEADERS)
+#if defined(HAVE_MALLOC_H) && !defined(HAVE_STDLIB_H)
 # include <malloc.h>
-#endif /* HAVE_MALLOC_H && !STDC_HEADERS */
+#endif /* HAVE_MALLOC_H && !HAVE_STDLIB_H */
 #ifdef HAVE_UNISTD_H
 # include <unistd.h>
 #endif /* HAVE_UNISTD_H */
@@ -54,7 +54,7 @@
 #include <extern.h>
 
 #ifndef lint
-static const char rcsid[] = "$Id: mkdtemp.c,v 1.3 2001/05/22 23:15:38 millert Exp $";
+static const char rcsid[] = "$Id: mkdtemp.c,v 1.4 2001/10/01 00:21:34 millert Exp $";
 #endif /* lint */
 
 /*
