@@ -1,4 +1,4 @@
-/*	$OpenBSD: mktemp.c,v 1.5 1998/06/21 22:14:00 millert Exp $	*/
+/*	$OpenBSD: mktemp.c,v 1.6 2001/10/01 17:08:30 millert Exp $	*/
 
 /*
  * Copyright (c) 1996, 2000, 2001 Todd C. Miller <Todd.Miller@courtesan.com>
@@ -27,29 +27,39 @@
  * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#ifndef lint                                                              
-static const char rcsid[] = "$Id: mktemp.c,v 1.3 2001/05/22 23:37:02 millert Exp $";
-#endif /* not lint */                                                        
-
 #include "config.h"
 
+#ifndef lint                                                              
+static const char rcsid[] = "$Id: mktemp.c,v 1.7 2001/10/02 16:53:18 millert Exp $";
+#endif /* not lint */                                                        
+
 #include <stdio.h>
-#ifdef STDC_HEADERS
+#ifdef HAVE_STDLIB_H
 #include <stdlib.h>
-#endif /* STDC_HEADERS */
+#endif /* HAVE_STDLIB_H */
 #ifdef HAVE_STRING_H
 #include <string.h>
 #endif /* HAVE_STRING_H */
 #ifdef HAVE_STRINGS_H
 #include <strings.h>
 #endif /* HAVE_STRINGS_H */
+#if defined(HAVE_MALLOC_H) && !defined(HAVE_STDLIB_H)
+#include <malloc.h>
+#endif /* HAVE_MALLOC_H && !HAVE_STDLIB_H */
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif /* HAVE_UNISTD_H */
+#ifdef HAVE_PATHS_H
+#include <paths.h>
+#endif /* HAVE_PATHS_H */
 #include <errno.h>
 
 #include <extern.h>
 
+#ifndef _PATH_TMP
+#define _PATH_TMP "/tmp"
+#endif
+
 #ifdef HAVE_PROGNAME
 extern char *__progname;
 #else
@@ -59,7 +69,9 @@ char *__progname;
 static void
 usage()
 {
-	(void) fprintf(stderr, "Usage: %s [-V] | [-d] [-q] [-u] template\n",
+
+	(void) fprintf(stderr,
+	    "Usage: %s [-V] | [-dqtu] [-p prefix] template\n",
 	    __progname);
 	exit(1);
 }
@@ -69,29 +81,37 @@ main(argc, argv)
 	int argc;
 	char **argv;
 {
-	char *template;
-	int c, uflag = 0, qflag = 0, makedir = 0;
+	int ch, uflag = 0, qflag = 0, tflag = 0, makedir = 0;
+	char *cp, *template, *prefix = _PATH_TMP;
+	size_t plen;
+	extern char *optarg;
 	extern int optind;
 
 #ifndef HAVE_PROGNAME
 	__progname = argv[0];
 #endif
 
-	while ((c = getopt(argc, argv, "dquV")) != -1)
-		switch(c) {
+	while ((ch = getopt(argc, argv, "dp:qtuV")) != -1)
+		switch(ch) {
 		case 'd':
 			makedir = 1;
 			break;
+		case 'p':
+			prefix = optarg;
+			tflag = 1;
+			break;
 		case 'q':
 			qflag = 1;
 			break;
+		case 't':
+			tflag = 1;
+			break;
 		case 'u':
 			uflag = 1;
 			break;
 		case 'V':
 			printf("%s version %s\n", __progname, MKTEMP_VERSION);
 			exit(0);
-		case 'h':
 		default:
 			usage();
 	}
@@ -99,11 +119,39 @@ main(argc, argv)
 	if (argc - optind != 1)
 		usage();
 
-	if ((template = strdup(argv[optind])) == NULL) {
-		if (!qflag)
-			(void) fprintf(stderr, "%s: cannot allocate memory\n",
-			    __progname);
-		exit(1);
+	if (tflag) {
+		if (strchr(argv[optind], '/')) {
+			if (!qflag)
+				(void) fprintf(stderr,
+				    "%s: template must not contain directory separators in -t mode\n", __progname);
+			exit(1);
+
+		}
+
+		cp = getenv("TMPDIR");
+		if (cp != NULL && *cp != '\0')
+			prefix = cp;
+		plen = strlen(prefix);
+		while (plen != 0 && prefix[plen - 1] == '/')
+			plen--;
+
+		template = (char *)malloc(plen + 1 + strlen(argv[optind]) + 1);
+		if (template == NULL) {
+			if (!qflag)
+				(void) fprintf(stderr,
+				    "%s: cannot allocate memory\n", __progname);
+			exit(1);
+		}
+		memcpy(template, prefix, plen);
+		template[plen] = '/';
+		strcpy(template + plen + 1, argv[optind]);	/* SAFE */
+	} else {
+		if ((template = strdup(argv[optind])) == NULL) {
+			if (!qflag)
+				(void) fprintf(stderr,
+				    "%s: cannot allocate memory\n", __progname);
+			exit(1);
+		}
 	}
 
 	if (makedir) {
